==> dnet-mapreduce-jobs-1.2.0-20190710.102729-95-sources.jar: eu/dnetlib/data/mapreduce/hbase/dataimport/DumpToActionsUtility.java <==
package eu.dnetlib.data.mapreduce.hbase.dataimport;

import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import eu.dnetlib.data.proto.FieldTypeProtos;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class DumpToActionsUtility {

    public static String getStringValue(final JsonObject root, final String key) {
        if (root.has(key) && !root.get(key).isJsonNull())
            return root.get(key).getAsString();
        return null;
    }

    public static List<String> getArrayValues(final JsonObject root, final String key) {
        if (root.has(key) && root.get(key).isJsonArray()) {
            final JsonArray asJsonArray = root.get(key).getAsJsonArray();
            final List<String> result = new ArrayList<>();


            asJsonArray.forEach(it -> {
                if (StringUtils.isNotBlank(it.getAsString())) {
                    result.add(it.getAsString());
                }
            });
            return result;
        }
        return new ArrayList<>();
    }
    public static List<JsonObject> getArrayObjects(final JsonObject root, final String key) {
        if (root.has(key) && root.get(key).isJsonArray()) {
            final JsonArray asJsonArray = root.get(key).getAsJsonArray();
            final List<JsonObject> result = new ArrayList<>();
            asJsonArray.forEach(it -> {
                if (it.getAsJsonObject() != null)  {
                    result.add(it.getAsJsonObject());
                }
            });
            return result;
        }
        return new ArrayList<>();
    }

    public static boolean isValidDate(final String date) {
        return date.matches("\\d{4}-\\d{2}-\\d{2}");
    }

    public static FieldTypeProtos.StructuredProperty getPid(final JsonObject localIdentifier, final Map<String, ScholExplorerConfiguration> conf) {
        final String pidType = getStringValue(localIdentifier, "type");
        final ScholExplorerConfiguration configuration = conf.get(pidType);
        if (configuration.getCleandPidType() == null) {
            return null;
        }
        final String pid = getStringValue(localIdentifier, "id");
        return FieldTypeProtos.StructuredProperty.newBuilder()
                .setValue(pid)
                .setQualifier(getQualifier(configuration.getCleandPidType(), "dnet:pid_types"))
                .build();
    }
    public static FieldTypeProtos.Qualifier getQualifier(final String classValue, final String schemeValue) {

        return FieldTypeProtos.Qualifier.newBuilder()
                .setSchemeid(schemeValue)
                .setSchemename(schemeValue)
                .setClassname(classValue)
                .setClassid(classValue)
                .build();
    }

    public static String getDefaultResulttype(final String cobjcategory) {
        switch (cobjcategory) {
            case "0029":
                return "software";
            case "0021":
            case "0024":
            case "0025":
            case "0030":
                return "dataset";
            case "0000":
            case "0010":
            case "0018":
            case "0020":
            case "0022":
            case "0023":
            case "0026":
            case "0027":
            case "0028":
            case "0037":
                return "other";
            case "0001":
            case "0002":
            case "0004":
            case "0005":
            case "0006":
            case "0007":
            case "0008":
            case "0009":
            case "0011":
            case "0012":
            case "0013":
            case "0014":
            case "0015":
            case "0016":
            case "0017":
            case "0019":
            case "0031":
            case "0032":
                return "publication";
            default:
                return "publication";
        }
    }

}

==> dnet-mapreduce-jobs-1.2.2-20201111.163901-133-sources.jar: eu/dnetlib/data/mapreduce/hbase/dataimport/DumpToActionsUtility.java <==
package eu.dnetlib.data.mapreduce.hbase.dataimport;

import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import eu.dnetlib.data.proto.FieldTypeProtos;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class DumpToActionsUtility {

    public static String getStringValue(final JsonObject root, final String key) {
        if (root.has(key) && !root.get(key).isJsonNull())
            return root.get(key).getAsString();
        return null;
    }

    public static List<String> getArrayValues(final JsonObject root, final String key) {
        if (root.has(key) && root.get(key).isJsonArray()) {
            final JsonArray asJsonArray = root.get(key).getAsJsonArray();
            final List<String> result = new ArrayList<>();


            asJsonArray.forEach(it -> {
                if (StringUtils.isNotBlank(it.getAsString())) {
                    result.add(it.getAsString());
                }
            });
            return result;
        }
        return new ArrayList<>();
    }
    public static List<JsonObject> getArrayObjects(final JsonObject root, final String key) {
        if (root.has(key) && root.get(key).isJsonArray()) {
            final JsonArray asJsonArray = root.get(key).getAsJsonArray();
            final List<JsonObject> result = new ArrayList<>();
            asJsonArray.forEach(it -> {
                if (it.getAsJsonObject() != null)  {
                    result.add(it.getAsJsonObject());
                }
            });
            return result;
        }
        return new ArrayList<>();
    }

    public static boolean isValidDate(final String date) {
        return date.matches("\\d{4}-\\d{1,2}-\\d{1,2}");
    }

    public static FieldTypeProtos.StructuredProperty getPid(final JsonObject localIdentifier, final Map<String, ScholExplorerConfiguration> conf) {
        final String pidType = getStringValue(localIdentifier, "type");
        final ScholExplorerConfiguration configuration = conf.get(pidType);
        if (configuration.getCleandPidType() == null) {
            return null;
        }
        final String pid = getStringValue(localIdentifier, "id");
        return FieldTypeProtos.StructuredProperty.newBuilder()
                .setValue(pid)
                .setQualifier(getQualifier(configuration.getCleandPidType(), "dnet:pid_types"))
                .build();
    }
    public static FieldTypeProtos.Qualifier getQualifier(final String classValue, final String schemeValue) {

        return FieldTypeProtos.Qualifier.newBuilder()
                .setSchemeid(schemeValue)
                .setSchemename(schemeValue)
                .setClassname(classValue)
                .setClassid(classValue)
                .build();
    }

    public static String getDefaultResulttype(final String cobjcategory) {
        switch (cobjcategory) {
            case "0029":
                return "software";
            case "0021":
            case "0024":
            case "0025":
            case "0030":
                return "dataset";
            case "0000":
            case "0010":
            case "0018":
            case "0020":
            case "0022":
            case "0023":
            case "0026":
            case "0027":
            case "0028":
            case "0037":
                return "other";
            case "0001":
            case "0002":
            case "0004":
            case "0005":
            case "0006":
            case "0007":
            case "0008":
            case "0009":
            case "0011":
            case "0012":
            case "0013":
            case "0014":
            case "0015":
            case "0016":
            case "0017":
            case "0019":
            case "0031":
            case "0032":
                return "publication";
            default:
                return "publication";
        }
    }

}
